:tocdepth: 2

================
VMExpiration API
================

This is a reference for the OpenStack VM expiration API which is provided by
the os-vm-expire project.

.. include:: vmexpire.inc
.. include:: vmexclude.inc
